ALTER SESSION SET "_ORACLE_SCRIPT"=true;

ALTER SESSION SET NLS_DATE_FORMAT='YYYY-MM-DD' NLS_TIMESTAMP_FORMAT='YYYY-MM-DD HH24:MI:SS.FF' NLS_TIMESTAMP_TZ_FORMAT='YYYY-MM-DD HH24:MI:SS.FF TZH:TZM';

CREATE USER S13
  IDENTIFIED BY "change_on_install"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

CREATE TABLE S13.QUOTES (
      "'" VARCHAR2(50) NOT NULL
    , "''" VARCHAR2(50) NOT NULL
    , "," VARCHAR2(50) NOT NULL
    , "-" VARCHAR2(50) NOT NULL
    , "@" VARCHAR2(50) NOT NULL
    , "@@" VARCHAR2(50) NOT NULL
    , "`" VARCHAR2(50) DEFAULT NULL
    , "``" VARCHAR2(50) DEFAULT NULL
    , "]" VARCHAR2(50) DEFAULT NULL
    , "[" VARCHAR2(50) DEFAULT NULL
    , "[]" VARCHAR2(50) DEFAULT NULL
    , "+" VARCHAR2(50) DEFAULT NULL
    , "*" VARCHAR2(50) DEFAULT NULL
    , "%" VARCHAR2(50) DEFAULT NULL
    , "%%" VARCHAR2(50) DEFAULT NULL
    , "=" VARCHAR2(50) DEFAULT NULL
    , ";" VARCHAR2(50) DEFAULT NULL
    , ":" VARCHAR2(50) DEFAULT NULL
    , "<>" VARCHAR2(50) DEFAULT NULL
    , "&" VARCHAR2(50) DEFAULT NULL
    , "." VARCHAR2(50) DEFAULT NULL
    , ".." VARCHAR2(50) DEFAULT NULL
    , CONSTRAINT PK_QUOTES PRIMARY KEY ("'", "''", ",", "-", "@", "@@")
);

CREATE TABLE S13.DATATYPES (
    "ID" NUMBER NOT NULL
    , "BINARY_DOUBLE" BINARY_DOUBLE DEFAULT NULL
    , "BINARY_FLOAT" BINARY_FLOAT DEFAULT NULL
    , "BLOB" BLOB DEFAULT NULL
    , "CHAR" CHAR(10) DEFAULT NULL
    , "CHAR36" CHAR(36) DEFAULT NULL
    , "CLOB" CLOB DEFAULT NULL
    , "DATE" DATE DEFAULT NULL
    , "FLOAT" FLOAT DEFAULT NULL
    , "FLOAT1" FLOAT(1) DEFAULT NULL
    , "FLOAT23" FLOAT(23) DEFAULT NULL
    , "FLOAT49" FLOAT(49) DEFAULT NULL
    , "FLOAT63" FLOAT(63) DEFAULT NULL
    , "INTERVAL_DS" INTERVAL DAY TO SECOND DEFAULT NULL
    , "INTERVAL_YM" INTERVAL YEAR TO MONTH DEFAULT NULL
    , "LONG" LONG DEFAULT NULL
    , "NCHAR" NCHAR(10) DEFAULT NULL
    , "NCLOB" NCLOB DEFAULT NULL
    , "NUMBER" NUMBER DEFAULT NULL
    , "NUMBER1" NUMBER(1) DEFAULT NULL
    , "NUMBER2" NUMBER(2) DEFAULT NULL
    , "NUMBER3" NUMBER(3) DEFAULT NULL
    , "NUMBER4" NUMBER(4) DEFAULT NULL
    , "NUMBER5" NUMBER(5) DEFAULT NULL
    , "NUMBER9" NUMBER(9) DEFAULT NULL
    , "NUMBER10" NUMBER(10) DEFAULT NULL
    , "NUMBER18" NUMBER(18) DEFAULT NULL
    , "NUMBER19" NUMBER(19) DEFAULT NULL
    , "NUMBER104" NUMBER(10,4) DEFAULT NULL
    , "NUMBER152" NUMBER(15,2) DEFAULT NULL
    , "NUMBER194" NUMBER(19,4) DEFAULT NULL
    , "NVARCHAR2" NVARCHAR2(255) DEFAULT NULL
    , "RAW" RAW(1024) DEFAULT NULL
    , "TIMESTAMP" TIMESTAMP DEFAULT NULL
    , "TIMESTAMP0" TIMESTAMP(0) DEFAULT NULL
    , "TIMESTAMP3" TIMESTAMP(3) DEFAULT NULL
    , "TIMESTAMP_LTZ" TIMESTAMP WITH LOCAL TIME ZONE DEFAULT NULL
    , "TIMESTAMP_LTZ0" TIMESTAMP(0) WITH LOCAL TIME ZONE DEFAULT NULL
    , "TIMESTAMP_LTZ3" TIMESTAMP(3) WITH LOCAL TIME ZONE DEFAULT NULL
    , "TIMESTAMP_TZ" TIMESTAMP WITH TIME ZONE DEFAULT NULL
    , "TIMESTAMP_TZ0" TIMESTAMP(0) WITH TIME ZONE DEFAULT NULL
    , "TIMESTAMP_TZ3" TIMESTAMP(3) WITH TIME ZONE DEFAULT NULL
    , "VARCHAR2" VARCHAR2(255) DEFAULT NULL
    , "XML" XMLType DEFAULT NULL
    , CONSTRAINT PK_DATATYPES PRIMARY KEY (ID)
);

CREATE SEQUENCE S13.SQ_DATATYPES_ID INCREMENT BY 1 START WITH 1 MAXVALUE 1E28 MINVALUE 1 NOCYCLE CACHE 20 NOORDER;

CREATE TRIGGER S13.TR_DATATYPES_ID
  BEFORE INSERT OR UPDATE ON S13.DATATYPES
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
    SELECT SQ_DATATYPES_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPE_COLUMNS (
    DATA OUT SYS_REFCURSOR
    )
AS
BEGIN

OPEN DATA FOR
SELECT
    c.OWNER AS TABLE_SCHEMA
    , c.TABLE_NAME
    , c.COLUMN_NAME
    , c.COLUMN_ID AS ORDINAL_POSITION
    , NULL AS IS_PRIMARY_KEY
    , c.NULLABLE AS IS_NULLABLE
    , NULL AS IS_IDENTITY
    , CASE WHEN c.VIRTUAL_COLUMN = 'YES' AND c.DATA_DEFAULT IS NOT NULL AND c.DATA_TYPE <> 'XMLTYPE' THEN 'YES' ELSE 'NO' END AS IS_COMPUTED
    , c.DATA_DEFAULT AS COLUMN_DEFAULT
    , c.DATA_TYPE
    , CASE WHEN c.DATA_PRECISION IS NOT NULL THEN NULL WHEN c.CHAR_LENGTH > 0 THEN c.CHAR_LENGTH ELSE c.DATA_LENGTH END AS MAX_LENGTH
    , c.DATA_PRECISION AS PRECISION
    , c.DATA_SCALE AS SCALE
FROM
    SYS.ALL_TAB_COLS c
WHERE
    c.OWNER = 'S13' AND c.TABLE_NAME = 'DATATYPES'
    AND c.HIDDEN_COLUMN = 'NO'
ORDER BY
    c.COLUMN_ID;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPE_PARAMETERS (
    DATA OUT SYS_REFCURSOR
    )
AS
BEGIN

OPEN DATA FOR
SELECT
    p.OWNER AS SPECIFIC_SCHEMA
    , p.OBJECT_NAME AS SPECIFIC_NAME
    , p.POSITION AS ORDINAL_POSITION
    , p.IN_OUT AS PARAMETER_MODE
    , p.ARGUMENT_NAME AS PARAMETER_NAME
    , p.DATA_TYPE AS DATA_TYPE
    , CASE WHEN p.DATA_PRECISION IS NOT NULL THEN NULL WHEN p.CHAR_LENGTH > 0 THEN p.CHAR_LENGTH ELSE p.DATA_LENGTH END AS MAX_LENGTH
    , p.DATA_PRECISION AS PRECISION
    , CASE WHEN p.DATA_SCALE = -127 THEN NULL ELSE p.DATA_SCALE END AS SCALE
FROM
    SYS.ALL_ARGUMENTS p
WHERE
    p.OWNER = 'S13' AND p.OBJECT_NAME IN ('USP_DATATYPES', 'USP_DATATYPES_INSERT', 'USP_DATATYPES_UPDATE', 'USP_DATATYPES_DELETE')
ORDER BY
    p.OWNER
    , p.OBJECT_NAME
    , p.POSITION;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES (
    DATA OUT SYS_REFCURSOR
    )
AS
BEGIN

OPEN DATA FOR
SELECT
      t."'"
    , t."''"
    , t.","
    , t."-"
    , t."@"
    , t."@@"
    , t."`"
    , t."``"
    , t."]"
    , t."["
    , t."[]"
    , t."+"
    , t."*"
    , t."%"
    , t."%%"
    , t."="
    , t.";"
    , t.":"
    , t."<>"
    , t."&"
    , t."."
    , t.".."
FROM
    S13.QUOTES t;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES_DELETE (
    "_x0027_" VARCHAR2
    , "_x0027__x0027_" VARCHAR2
    , "_x002C_" VARCHAR2
    , "_x002D_" VARCHAR2
    , "_x0040_" VARCHAR2
    , "_x0040__x0040_" VARCHAR2
    )
AS
BEGIN

DELETE FROM S13.QUOTES
WHERE
    "'" = "_x0027_"
    AND "''" = "_x0027__x0027_"
    AND "," = "_x002C_"
    AND "-" = "_x002D_"
    AND "@" = "_x0040_"
    AND "@@" = "_x0040__x0040_";

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES_INSERT (
    "_x0027_" VARCHAR2
    , "_x0027__x0027_" VARCHAR2
    , "_x002C_" VARCHAR2
    , "_x002D_" VARCHAR2
    , "_x0040_" VARCHAR2
    , "_x0040__x0040_" VARCHAR2
    , "_x0060_" VARCHAR2
    , "_x0060__x0060_" VARCHAR2
    , "_x005D_" VARCHAR2
    , "_x005B_" VARCHAR2
    , "_x005B__x005D_" VARCHAR2
    , "_x002B_" VARCHAR2
    , "_x002A_" VARCHAR2
    , "_x0025_" VARCHAR2
    , "_x0025__x0025_" VARCHAR2
    , "_x003D_" VARCHAR2
    , "_x003B_" VARCHAR2
    , "_x003A_" VARCHAR2
    , "_x003C__x003E_" VARCHAR2
    , "_x0026_" VARCHAR2
    , "_x002E_" VARCHAR2
    , "_x002E__x002E_" VARCHAR2
    )
AS
BEGIN

INSERT INTO S13.QUOTES
    ( "'"
    , "''"
    , ","
    , "-"
    , "@"
    , "@@"
    , "`"
    , "``"
    , "]"
    , "["
    , "[]"
    , "+"
    , "*"
    , "%"
    , "%%"
    , "="
    , ";"
    , ":"
    , "<>"
    , "&"
    , "."
    , ".."
    )
VALUES
    ( "_x0027_"
    , "_x0027__x0027_"
    , "_x002C_"
    , "_x002D_"
    , "_x0040_"
    , "_x0040__x0040_"
    , "_x0060_"
    , "_x0060__x0060_"
    , "_x005D_"
    , "_x005B_"
    , "_x005B__x005D_"
    , "_x002B_"
    , "_x002A_"
    , "_x0025_"
    , "_x0025__x0025_"
    , "_x003D_"
    , "_x003B_"
    , "_x003A_"
    , "_x003C__x003E_"
    , "_x0026_"
    , "_x002E_"
    , "_x002E__x002E_"
    );

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES_UPDATE (
    "_x0027_" VARCHAR2
    , "_x0027__x0027_" VARCHAR2
    , "_x002C_" VARCHAR2
    , "_x002D_" VARCHAR2
    , "_x0040_" VARCHAR2
    , "_x0040__x0040_" VARCHAR2
    , "_x0060_" VARCHAR2
    , "_x0060__x0060_" VARCHAR2
    , "_x005D_" VARCHAR2
    , "_x005B_" VARCHAR2
    , "_x005B__x005D_" VARCHAR2
    , "_x002B_" VARCHAR2
    , "_x002A_" VARCHAR2
    , "_x0025_" VARCHAR2
    , "_x0025__x0025_" VARCHAR2
    , "_x003D_" VARCHAR2
    , "_x003B_" VARCHAR2
    , "_x003A_" VARCHAR2
    , "_x003C__x003E_" VARCHAR2
    , "_x0026_" VARCHAR2
    , "_x002E_" VARCHAR2
    , "_x002E__x002E_" VARCHAR2
    )
AS
BEGIN

UPDATE S13.QUOTES
SET
    "`" = "_x0060_"
    , "``" = "_x0060__x0060_"
    , "]" = "_x005D_"
    , "[" = "_x005B_"
    , "[]" = "_x005B__x005D_"
    , "+" = "_x002B_"
    , "*" = "_x002A_"
    , "%" = "_x0025_"
    , "%%" = "_x0025__x0025_"
    , "=" = "_x003D_"
    , ";" = "_x003B_"
    , ":" = "_x003A_"
    , "<>" = "_x003C__x003E_"
    , "&" = "_x0026_"
    , "." = "_x002E_"
    , ".." = "_x002E__x002E_"
WHERE
    "'" = "_x0027_"
    AND "''" = "_x0027__x0027_"
    AND "," = "_x002C_"
    AND "-" = "_x002D_"
    AND "@" = "_x0040_"
    AND "@@" = "_x0040__x0040_";

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES (
    DATA OUT SYS_REFCURSOR
    )
AS
BEGIN

OPEN DATA FOR
SELECT
    t."ID"
    , t."BINARY_DOUBLE"
    , t."BINARY_FLOAT"
    , t."BLOB"
    , t."CHAR"
    , t."CHAR36"
    , t."CLOB"
    , t."DATE"
    , t."FLOAT"
    , t."FLOAT1"
    , t."FLOAT23"
    , t."FLOAT49"
    , t."FLOAT63"
    , t."INTERVAL_DS"
    , t."INTERVAL_YM"
    , t."LONG"
    , t."NCHAR"
    , t."NCLOB"
    , t."NUMBER"
    , t."NUMBER1"
    , t."NUMBER2"
    , t."NUMBER3"
    , t."NUMBER4"
    , t."NUMBER5"
    , t."NUMBER9"
    , t."NUMBER10"
    , t."NUMBER18"
    , t."NUMBER19"
    , t."NUMBER104"
    , t."NUMBER152"
    , t."NUMBER194"
    , t."NVARCHAR2"
    , t."RAW"
    , t."TIMESTAMP"
    , t."TIMESTAMP0"
    , t."TIMESTAMP3"
    , t."TIMESTAMP_LTZ"
    , t."TIMESTAMP_LTZ0"
    , t."TIMESTAMP_LTZ3"
    , t."TIMESTAMP_TZ"
    , t."TIMESTAMP_TZ0"
    , t."TIMESTAMP_TZ3"
    , t."VARCHAR2"
    , t."XML"
FROM
    S13.DATATYPES t;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES_DELETE (
    ID NUMBER
    )
AS
BEGIN

DELETE FROM S13.DATATYPES
WHERE
    ID = USP_DATATYPES_DELETE.ID;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES_INSERT (
    "BINARY_DOUBLE" BINARY_DOUBLE
    , "BINARY_FLOAT" BINARY_FLOAT
    , "BLOB" BLOB
    , "CHAR" CHAR
    , "CHAR36" CHAR
    , "CLOB" CLOB
    , "DATE" DATE
    , "FLOAT" FLOAT
    , "FLOAT1" FLOAT
    , "FLOAT23" FLOAT
    , "FLOAT49" FLOAT
    , "FLOAT63" FLOAT
    , "INTERVAL_DS" INTERVAL DAY TO SECOND
    , "INTERVAL_YM" INTERVAL YEAR TO MONTH
    , "LONG" LONG
    , "NCHAR" NCHAR
    , "NCLOB" NCLOB
    , "NUMBER" NUMBER
    , "NUMBER1" NUMBER
    , "NUMBER2" NUMBER
    , "NUMBER3" NUMBER
    , "NUMBER4" NUMBER
    , "NUMBER5" NUMBER
    , "NUMBER9" NUMBER
    , "NUMBER10" NUMBER
    , "NUMBER18" NUMBER
    , "NUMBER19" NUMBER
    , "NUMBER104" NUMBER
    , "NUMBER152" NUMBER
    , "NUMBER194" NUMBER
    , "NVARCHAR2" NVARCHAR2
    , "RAW" RAW
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP
    , "TIMESTAMP3" TIMESTAMP
    , "TIMESTAMP_LTZ" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ0" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ3" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_TZ" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ0" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ3" TIMESTAMP WITH TIME ZONE
    , "VARCHAR2" VARCHAR2
    , "XML" XMLType
    )
AS
BEGIN

INSERT INTO S13.DATATYPES
    ( "BINARY_DOUBLE"
    , "BINARY_FLOAT"
    , "BLOB"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "FLOAT"
    , "FLOAT1"
    , "FLOAT23"
    , "FLOAT49"
    , "FLOAT63"
    , "INTERVAL_DS"
    , "INTERVAL_YM"
    , "LONG"
    , "NCHAR"
    , "NCLOB"
    , "NUMBER"
    , "NUMBER1"
    , "NUMBER2"
    , "NUMBER3"
    , "NUMBER4"
    , "NUMBER5"
    , "NUMBER9"
    , "NUMBER10"
    , "NUMBER18"
    , "NUMBER19"
    , "NUMBER104"
    , "NUMBER152"
    , "NUMBER194"
    , "NVARCHAR2"
    , "RAW"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "TIMESTAMP_LTZ"
    , "TIMESTAMP_LTZ0"
    , "TIMESTAMP_LTZ3"
    , "TIMESTAMP_TZ"
    , "TIMESTAMP_TZ0"
    , "TIMESTAMP_TZ3"
    , "VARCHAR2"
    , "XML"
    )
VALUES
    ( "BINARY_DOUBLE"
    , "BINARY_FLOAT"
    , "BLOB"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "FLOAT"
    , "FLOAT1"
    , "FLOAT23"
    , "FLOAT49"
    , "FLOAT63"
    , "INTERVAL_DS"
    , "INTERVAL_YM"
    , "LONG"
    , "NCHAR"
    , "NCLOB"
    , "NUMBER"
    , "NUMBER1"
    , "NUMBER2"
    , "NUMBER3"
    , "NUMBER4"
    , "NUMBER5"
    , "NUMBER9"
    , "NUMBER10"
    , "NUMBER18"
    , "NUMBER19"
    , "NUMBER104"
    , "NUMBER152"
    , "NUMBER194"
    , "NVARCHAR2"
    , "RAW"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "TIMESTAMP_LTZ"
    , "TIMESTAMP_LTZ0"
    , "TIMESTAMP_LTZ3"
    , "TIMESTAMP_TZ"
    , "TIMESTAMP_TZ0"
    , "TIMESTAMP_TZ3"
    , "VARCHAR2"
    , "XML"
    );

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES_UPDATE (
    "ID" NUMBER
    , "BINARY_DOUBLE" BINARY_DOUBLE
    , "BINARY_FLOAT" BINARY_FLOAT
    , "BLOB" BLOB
    , "CHAR" CHAR
    , "CHAR36" CHAR
    , "CLOB" CLOB
    , "DATE" DATE
    , "FLOAT" FLOAT
    , "FLOAT1" FLOAT
    , "FLOAT23" FLOAT
    , "FLOAT49" FLOAT
    , "FLOAT63" FLOAT
    , "INTERVAL_DS" INTERVAL DAY TO SECOND
    , "INTERVAL_YM" INTERVAL YEAR TO MONTH
    , "LONG" LONG
    , "NCHAR" NCHAR
    , "NCLOB" NCLOB
    , "NUMBER" NUMBER
    , "NUMBER1" NUMBER
    , "NUMBER2" NUMBER
    , "NUMBER3" NUMBER
    , "NUMBER4" NUMBER
    , "NUMBER5" NUMBER
    , "NUMBER9" NUMBER
    , "NUMBER10" NUMBER
    , "NUMBER18" NUMBER
    , "NUMBER19" NUMBER
    , "NUMBER104" NUMBER
    , "NUMBER152" NUMBER
    , "NUMBER194" NUMBER
    , "NVARCHAR2" NVARCHAR2
    , "RAW" RAW
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP
    , "TIMESTAMP3" TIMESTAMP
    , "TIMESTAMP_LTZ" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ0" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ3" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_TZ" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ0" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ3" TIMESTAMP WITH TIME ZONE
    , "VARCHAR2" VARCHAR2
    , "XML" XMLType
    )
AS
BEGIN

UPDATE S13.DATATYPES
SET
    "BINARY_DOUBLE" = USP_DATATYPES_UPDATE."BINARY_DOUBLE"
    , "BINARY_FLOAT" = USP_DATATYPES_UPDATE."BINARY_FLOAT"
    , "BLOB" = USP_DATATYPES_UPDATE."BLOB"
    , "CHAR" = USP_DATATYPES_UPDATE."CHAR"
    , "CHAR36" = USP_DATATYPES_UPDATE."CHAR36"
    , "CLOB" = USP_DATATYPES_UPDATE."CLOB"
    , "DATE" = USP_DATATYPES_UPDATE."DATE"
    , "FLOAT" = USP_DATATYPES_UPDATE."FLOAT"
    , "FLOAT1" = USP_DATATYPES_UPDATE."FLOAT1"
    , "FLOAT23" = USP_DATATYPES_UPDATE."FLOAT23"
    , "FLOAT49" = USP_DATATYPES_UPDATE."FLOAT49"
    , "FLOAT63" = USP_DATATYPES_UPDATE."FLOAT63"
    , "INTERVAL_DS" = USP_DATATYPES_UPDATE."INTERVAL_DS"
    , "INTERVAL_YM" = USP_DATATYPES_UPDATE."INTERVAL_YM"
    , "LONG" = USP_DATATYPES_UPDATE."LONG"
    , "NCHAR" = USP_DATATYPES_UPDATE."NCHAR"
    , "NCLOB" = USP_DATATYPES_UPDATE."NCLOB"
    , "NUMBER" = USP_DATATYPES_UPDATE."NUMBER"
    , "NUMBER1" = USP_DATATYPES_UPDATE."NUMBER1"
    , "NUMBER2" = USP_DATATYPES_UPDATE."NUMBER2"
    , "NUMBER3" = USP_DATATYPES_UPDATE."NUMBER3"
    , "NUMBER4" = USP_DATATYPES_UPDATE."NUMBER4"
    , "NUMBER5" = USP_DATATYPES_UPDATE."NUMBER5"
    , "NUMBER9" = USP_DATATYPES_UPDATE."NUMBER9"
    , "NUMBER10" = USP_DATATYPES_UPDATE."NUMBER10"
    , "NUMBER18" = USP_DATATYPES_UPDATE."NUMBER18"
    , "NUMBER19" = USP_DATATYPES_UPDATE."NUMBER19"
    , "NUMBER104" = USP_DATATYPES_UPDATE."NUMBER104"
    , "NUMBER152" = USP_DATATYPES_UPDATE."NUMBER152"
    , "NUMBER194" = USP_DATATYPES_UPDATE."NUMBER194"
    , "NVARCHAR2" = USP_DATATYPES_UPDATE."NVARCHAR2"
    , "RAW" = USP_DATATYPES_UPDATE."RAW"
    , "TIMESTAMP" = USP_DATATYPES_UPDATE."TIMESTAMP"
    , "TIMESTAMP0" = USP_DATATYPES_UPDATE."TIMESTAMP0"
    , "TIMESTAMP3" = USP_DATATYPES_UPDATE."TIMESTAMP3"
    , "TIMESTAMP_LTZ" = USP_DATATYPES_UPDATE."TIMESTAMP_LTZ"
    , "TIMESTAMP_LTZ0" = USP_DATATYPES_UPDATE."TIMESTAMP_LTZ0"
    , "TIMESTAMP_LTZ3" = USP_DATATYPES_UPDATE."TIMESTAMP_LTZ3"
    , "TIMESTAMP_TZ" = USP_DATATYPES_UPDATE."TIMESTAMP_TZ"
    , "TIMESTAMP_TZ0" = USP_DATATYPES_UPDATE."TIMESTAMP_TZ0"
    , "TIMESTAMP_TZ3" = USP_DATATYPES_UPDATE."TIMESTAMP_TZ3"
    , "VARCHAR2" = USP_DATATYPES_UPDATE."VARCHAR2"
    , "XML" = USP_DATATYPES_UPDATE."XML"
WHERE
    ID = USP_DATATYPES_UPDATE.ID;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES (
    DATA OUT SYS_REFCURSOR
    )
AS
BEGIN

OPEN DATA FOR
SELECT
    t."ID"
    , t."BINARY_DOUBLE"
    , t."BINARY_FLOAT"
    , t."BLOB"
    , t."CHAR"
    , t."CHAR36"
    , t."CLOB"
    , TO_CHAR(t."DATE") AS "DATE"
    , TO_CHAR(t."FLOAT") AS "FLOAT"
    , t."FLOAT1"
    , t."FLOAT23"
    , t."FLOAT49"
    , TO_CHAR(t."FLOAT63") AS "FLOAT63"
    , TO_CHAR(t."INTERVAL_DS") AS "INTERVAL_DS"
    , TO_CHAR(t."INTERVAL_YM") AS "INTERVAL_YM"
    , t."LONG"
    , t."NCHAR"
    , t."NCLOB"
    , TO_CHAR(t."NUMBER") AS "NUMBER"
    , t."NUMBER1"
    , t."NUMBER2"
    , t."NUMBER3"
    , t."NUMBER4"
    , t."NUMBER5"
    , t."NUMBER9"
    , t."NUMBER10"
    , TO_CHAR(t."NUMBER18") AS "NUMBER18"
    , TO_CHAR(t."NUMBER19") AS "NUMBER19"
    , t."NUMBER104"
    , t."NUMBER152"
    , TO_CHAR(t."NUMBER194") AS "NUMBER194"
    , t."NVARCHAR2"
    , RAWTOHEX(t."RAW") AS "RAW"
    , TO_CHAR(t."TIMESTAMP", 'YYYY-MM-DD HH24:MI:SS.FF') AS "TIMESTAMP"
    , t."TIMESTAMP0"
    , TO_CHAR(t."TIMESTAMP3", 'YYYY-MM-DD HH24:MI:SS.FF') AS "TIMESTAMP3"
    , TO_CHAR(t."TIMESTAMP_LTZ", 'YYYY-MM-DD HH24:MI:SS.FF') AS "TIMESTAMP_LTZ"
    , t."TIMESTAMP_LTZ0"
    , TO_CHAR(t."TIMESTAMP_LTZ3", 'YYYY-MM-DD HH24:MI:SS.FF') AS "TIMESTAMP_LTZ3"
    , TO_CHAR(t."TIMESTAMP_TZ", 'YYYY-MM-DD HH24:MI:SS.FF TZH:TZM') AS "TIMESTAMP_TZ"
    , TO_CHAR(t."TIMESTAMP_TZ0", 'YYYY-MM-DD HH24:MI:SS TZH:TZM') AS "TIMESTAMP_TZ0"
    , TO_CHAR(t."TIMESTAMP_TZ3", 'YYYY-MM-DD HH24:MI:SS.FF TZH:TZM') AS "TIMESTAMP_TZ3"
    , t."VARCHAR2"
    , t."XML".getClobVal() AS "XML"
FROM
    S13.DATATYPES t;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES_DELETE (
    ID NUMBER
    )
AS
BEGIN

DELETE FROM S13.DATATYPES
WHERE
    ID = USP_ODBC_DATATYPES_DELETE.ID;

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES_INSERT (
    "BINARY_DOUBLE" BINARY_DOUBLE
    , "BINARY_FLOAT" BINARY_FLOAT
    , "BLOB" BLOB
    , "CHAR" CHAR
    , "CHAR36" CHAR
    , "CLOB" CLOB
    , "DATE" DATE
    , "FLOAT" FLOAT
    , "FLOAT1" FLOAT
    , "FLOAT23" FLOAT
    , "FLOAT49" FLOAT
    , "FLOAT63" FLOAT
    , "INTERVAL_DS" INTERVAL DAY TO SECOND
    , "INTERVAL_YM" INTERVAL YEAR TO MONTH
    , "LONG" LONG
    , "NCHAR" NCHAR
    , "NCLOB" NCLOB
    , "NUMBER" NUMBER
    , "NUMBER1" NUMBER
    , "NUMBER2" NUMBER
    , "NUMBER3" NUMBER
    , "NUMBER4" NUMBER
    , "NUMBER5" NUMBER
    , "NUMBER9" NUMBER
    , "NUMBER10" NUMBER
    , "NUMBER18" NUMBER
    , "NUMBER19" NUMBER
    , "NUMBER104" NUMBER
    , "NUMBER152" NUMBER
    , "NUMBER194" NUMBER
    , "NVARCHAR2" NVARCHAR2
    , "RAW" RAW
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP
    , "TIMESTAMP3" TIMESTAMP
    , "TIMESTAMP_LTZ" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ0" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ3" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_TZ" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ0" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ3" TIMESTAMP WITH TIME ZONE
    , "VARCHAR2" VARCHAR2
    , "XML" CLOB
    )
AS
BEGIN

INSERT INTO S13.DATATYPES
    ( "BINARY_DOUBLE"
    , "BINARY_FLOAT"
    , "BLOB"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "FLOAT"
    , "FLOAT1"
    , "FLOAT23"
    , "FLOAT49"
    , "FLOAT63"
    , "INTERVAL_DS"
    , "INTERVAL_YM"
    , "LONG"
    , "NCHAR"
    , "NCLOB"
    , "NUMBER"
    , "NUMBER1"
    , "NUMBER2"
    , "NUMBER3"
    , "NUMBER4"
    , "NUMBER5"
    , "NUMBER9"
    , "NUMBER10"
    , "NUMBER18"
    , "NUMBER19"
    , "NUMBER104"
    , "NUMBER152"
    , "NUMBER194"
    , "NVARCHAR2"
    , "RAW"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "TIMESTAMP_LTZ"
    , "TIMESTAMP_LTZ0"
    , "TIMESTAMP_LTZ3"
    , "TIMESTAMP_TZ"
    , "TIMESTAMP_TZ0"
    , "TIMESTAMP_TZ3"
    , "VARCHAR2"
    , "XML"
    )
VALUES
    ( "BINARY_DOUBLE"
    , "BINARY_FLOAT"
    , "BLOB"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "FLOAT"
    , "FLOAT1"
    , "FLOAT23"
    , "FLOAT49"
    , "FLOAT63"
    , "INTERVAL_DS"
    , "INTERVAL_YM"
    , "LONG"
    , "NCHAR"
    , "NCLOB"
    , "NUMBER"
    , "NUMBER1"
    , "NUMBER2"
    , "NUMBER3"
    , "NUMBER4"
    , "NUMBER5"
    , "NUMBER9"
    , "NUMBER10"
    , "NUMBER18"
    , "NUMBER19"
    , "NUMBER104"
    , "NUMBER152"
    , "NUMBER194"
    , "NVARCHAR2"
    , "RAW"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "TIMESTAMP_LTZ"
    , "TIMESTAMP_LTZ0"
    , "TIMESTAMP_LTZ3"
    , "TIMESTAMP_TZ"
    , "TIMESTAMP_TZ0"
    , "TIMESTAMP_TZ3"
    , "VARCHAR2"
    , XMLTYPE(USP_ODBC_DATATYPES_INSERT."XML")
    );

END;
/

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES_UPDATE (
    "ID" NUMBER
    , "BINARY_DOUBLE" BINARY_DOUBLE
    , "BINARY_FLOAT" BINARY_FLOAT
    , "BLOB" BLOB
    , "CHAR" CHAR
    , "CHAR36" CHAR
    , "CLOB" CLOB
    , "DATE" DATE
    , "FLOAT" FLOAT
    , "FLOAT1" FLOAT
    , "FLOAT23" FLOAT
    , "FLOAT49" FLOAT
    , "FLOAT63" FLOAT
    , "INTERVAL_DS" INTERVAL DAY TO SECOND
    , "INTERVAL_YM" INTERVAL YEAR TO MONTH
    , "LONG" LONG
    , "NCHAR" NCHAR
    , "NCLOB" NCLOB
    , "NUMBER" NUMBER
    , "NUMBER1" NUMBER
    , "NUMBER2" NUMBER
    , "NUMBER3" NUMBER
    , "NUMBER4" NUMBER
    , "NUMBER5" NUMBER
    , "NUMBER9" NUMBER
    , "NUMBER10" NUMBER
    , "NUMBER18" NUMBER
    , "NUMBER19" NUMBER
    , "NUMBER104" NUMBER
    , "NUMBER152" NUMBER
    , "NUMBER194" NUMBER
    , "NVARCHAR2" NVARCHAR2
    , "RAW" RAW
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP
    , "TIMESTAMP3" TIMESTAMP
    , "TIMESTAMP_LTZ" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ0" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_LTZ3" TIMESTAMP WITH LOCAL TIME ZONE
    , "TIMESTAMP_TZ" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ0" TIMESTAMP WITH TIME ZONE
    , "TIMESTAMP_TZ3" TIMESTAMP WITH TIME ZONE
    , "VARCHAR2" VARCHAR2
    , "XML" CLOB
    )
AS
BEGIN

UPDATE S13.DATATYPES
SET
    "BINARY_DOUBLE" = USP_ODBC_DATATYPES_UPDATE."BINARY_DOUBLE"
    , "BINARY_FLOAT" = USP_ODBC_DATATYPES_UPDATE."BINARY_FLOAT"
    , "BLOB" = USP_ODBC_DATATYPES_UPDATE."BLOB"
    , "CHAR" = USP_ODBC_DATATYPES_UPDATE."CHAR"
    , "CHAR36" = USP_ODBC_DATATYPES_UPDATE."CHAR36"
    , "CLOB" = USP_ODBC_DATATYPES_UPDATE."CLOB"
    , "DATE" = USP_ODBC_DATATYPES_UPDATE."DATE"
    , "FLOAT" = USP_ODBC_DATATYPES_UPDATE."FLOAT"
    , "FLOAT1" = USP_ODBC_DATATYPES_UPDATE."FLOAT1"
    , "FLOAT23" = USP_ODBC_DATATYPES_UPDATE."FLOAT23"
    , "FLOAT49" = USP_ODBC_DATATYPES_UPDATE."FLOAT49"
    , "FLOAT63" = USP_ODBC_DATATYPES_UPDATE."FLOAT63"
    , "INTERVAL_DS" = USP_ODBC_DATATYPES_UPDATE."INTERVAL_DS"
    , "INTERVAL_YM" = USP_ODBC_DATATYPES_UPDATE."INTERVAL_YM"
    , "LONG" = USP_ODBC_DATATYPES_UPDATE."LONG"
    , "NCHAR" = USP_ODBC_DATATYPES_UPDATE."NCHAR"
    , "NCLOB" = USP_ODBC_DATATYPES_UPDATE."NCLOB"
    , "NUMBER" = USP_ODBC_DATATYPES_UPDATE."NUMBER"
    , "NUMBER1" = USP_ODBC_DATATYPES_UPDATE."NUMBER1"
    , "NUMBER2" = USP_ODBC_DATATYPES_UPDATE."NUMBER2"
    , "NUMBER3" = USP_ODBC_DATATYPES_UPDATE."NUMBER3"
    , "NUMBER4" = USP_ODBC_DATATYPES_UPDATE."NUMBER4"
    , "NUMBER5" = USP_ODBC_DATATYPES_UPDATE."NUMBER5"
    , "NUMBER9" = USP_ODBC_DATATYPES_UPDATE."NUMBER9"
    , "NUMBER10" = USP_ODBC_DATATYPES_UPDATE."NUMBER10"
    , "NUMBER18" = USP_ODBC_DATATYPES_UPDATE."NUMBER18"
    , "NUMBER19" = USP_ODBC_DATATYPES_UPDATE."NUMBER19"
    , "NUMBER104" = USP_ODBC_DATATYPES_UPDATE."NUMBER104"
    , "NUMBER152" = USP_ODBC_DATATYPES_UPDATE."NUMBER152"
    , "NUMBER194" = USP_ODBC_DATATYPES_UPDATE."NUMBER194"
    , "NVARCHAR2" = USP_ODBC_DATATYPES_UPDATE."NVARCHAR2"
    , "RAW" = USP_ODBC_DATATYPES_UPDATE."RAW"
    , "TIMESTAMP" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP"
    , "TIMESTAMP0" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP0"
    , "TIMESTAMP3" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP3"
    , "TIMESTAMP_LTZ" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP_LTZ"
    , "TIMESTAMP_LTZ0" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP_LTZ0"
    , "TIMESTAMP_LTZ3" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP_LTZ3"
    , "TIMESTAMP_TZ" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP_TZ"
    , "TIMESTAMP_TZ0" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP_TZ0"
    , "TIMESTAMP_TZ3" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP_TZ3"
    , "VARCHAR2" = USP_ODBC_DATATYPES_UPDATE."VARCHAR2"
    , "XML" = XMLTYPE(USP_ODBC_DATATYPES_UPDATE."XML")
WHERE
    ID = USP_ODBC_DATATYPES_UPDATE.ID;

END;
/

INSERT INTO "S13"."DATATYPES" ("ID","BINARY_DOUBLE","BINARY_FLOAT","BLOB","CHAR","CHAR36","CLOB","DATE","FLOAT","FLOAT1","FLOAT23","FLOAT49","FLOAT63","INTERVAL_DS","INTERVAL_YM","LONG","NCHAR","NCLOB","NUMBER","NUMBER1","NUMBER2","NUMBER3","NUMBER4","NUMBER5","NUMBER9","NUMBER10","NUMBER18","NUMBER19","NUMBER104","NUMBER152","NUMBER194","NVARCHAR2","RAW","TIMESTAMP","TIMESTAMP0","TIMESTAMP3","TIMESTAMP_LTZ","TIMESTAMP_LTZ0","TIMESTAMP_LTZ3","TIMESTAMP_TZ","TIMESTAMP_TZ0","TIMESTAMP_TZ3","VARCHAR2","XML") VALUES (1,1234545678901.12,12345.12,'0A0B0C','char      ','00010203-0405-0607-0809-0a0b0c0d0e0f','clob','2021-12-10',1234567890123456789.12,1,12345.12,1234545678901.12,12345456789012345.12,'2 10:30:00.000','2-1','long','nchar     ','nclob',1234567890123456789.1234,9,12,999,1234,12345,123456789,'1234567890','123456789012345678',1234567890123456789,123456.1234,1234567890123.12,123456789012345.1234,'nvarchar2','0A0B0C','2021-12-10 15:20:10.1234560','2021-12-10 15:20:10','2021-12-10 15:20:10.123','2021-12-10 15:20:10.1234560','2021-12-10 15:20:10','2021-12-10 15:20:10.123','2021-10-12 15:20:10.1234560 +00:00','2021-10-12 15:20:10.0000000 +00:00','2021-10-12 15:20:10.1230000 +00:00','varchar','<root/>');
INSERT INTO "S13"."DATATYPES" ("ID","BINARY_DOUBLE","BINARY_FLOAT","BLOB","CHAR","CHAR36","CLOB","DATE","FLOAT","FLOAT1","FLOAT23","FLOAT49","FLOAT63","INTERVAL_DS","INTERVAL_YM","LONG","NCHAR","NCLOB","NUMBER","NUMBER1","NUMBER2","NUMBER3","NUMBER4","NUMBER5","NUMBER9","NUMBER10","NUMBER18","NUMBER19","NUMBER104","NUMBER152","NUMBER194","NVARCHAR2","RAW","TIMESTAMP","TIMESTAMP0","TIMESTAMP3","TIMESTAMP_LTZ","TIMESTAMP_LTZ0","TIMESTAMP_LTZ3","TIMESTAMP_TZ","TIMESTAMP_TZ0","TIMESTAMP_TZ3","VARCHAR2","XML") VALUES (2,1234545678901.12,12345.12,'0A0B0C','char      ','00010203-0405-0607-0809-0a0b0c0d0e0f','clob','2021-12-10',1234567890123456789.12,1,12345.12,1234545678901.12,12345456789012345.12,'2 10:30:00.000','2-1','long','nchar     ','nclob',1234567890123456789.1234,9,12,999,1234,12345,123456789,'1234567890','123456789012345678',1234567890123456789,123456.1234,1234567890123.12,123456789012345.1234,'nvarchar2','0A0B0C','2021-12-10 15:20:10.1234560','2021-12-10 15:20:10','2021-12-10 15:20:10.123','2021-12-10 15:20:10.1234560','2021-12-10 15:20:10','2021-12-10 15:20:10.123','2021-10-12 15:20:10.1234560 +00:00','2021-10-12 15:20:10.0000000 +00:00','2021-10-12 15:20:10.1230000 +00:00','varchar','<root/>');
INSERT INTO "S13"."DATATYPES" ("ID","BINARY_DOUBLE","BINARY_FLOAT","BLOB","CHAR","CHAR36","CLOB","DATE","FLOAT","FLOAT1","FLOAT23","FLOAT49","FLOAT63","INTERVAL_DS","INTERVAL_YM","LONG","NCHAR","NCLOB","NUMBER","NUMBER1","NUMBER2","NUMBER3","NUMBER4","NUMBER5","NUMBER9","NUMBER10","NUMBER18","NUMBER19","NUMBER104","NUMBER152","NUMBER194","NVARCHAR2","RAW","TIMESTAMP","TIMESTAMP0","TIMESTAMP3","TIMESTAMP_LTZ","TIMESTAMP_LTZ0","TIMESTAMP_LTZ3","TIMESTAMP_TZ","TIMESTAMP_TZ0","TIMESTAMP_TZ3","VARCHAR2","XML") VALUES (3,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);

INSERT INTO "S13"."QUOTES" ("'", "''", ",", "-", "@", "@@", "`", "``", "]", "[", "[]", "+", "*", "%", "%%", "=", ";", ":", "<>", "&", ".", "..") VALUES ('''', '''''', ',', '-', '@', '@@', '`', '``', ']', '[', '[]', '+', '*', '%', '%%', '=', ';', ':', '<>', '&', '.', '..');
INSERT INTO "S13"."QUOTES" ("'", "''", ",", "-", "@", "@@", "`", "``", "]", "[", "[]", "+", "*", "%", "%%", "=", ";", ":", "<>", "&", ".", "..") VALUES ('1', '2', '3', '4', '5', '6', '`', '``', ']', '[', '[]', '+', '*', '%', '%%', '=', ';', ':', '<>', '&', '.', '..');

prompt Application installed
