UPDATE XLS.HANDLERS  SET HANDLER_CODE = 'TABLE, VIEW, PROCEDURE, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET' WHERE TABLE_SCHEMA = 'XLS' AND TABLE_NAME = 'HANDLERS' AND COLUMN_NAME = 'HANDLER_TYPE' AND EVENT_NAME = 'ValidationList';

CREATE OR REPLACE VIEW XLS.QUERIES (
    TABLE_SCHEMA,
    TABLE_NAME,
    TABLE_TYPE,
    TABLE_CODE,
    INSERT_PROCEDURE,
    UPDATE_PROCEDURE,
    DELETE_PROCEDURE,
    PROCEDURE_TYPE
)
AS
SELECT
    t.OWNER AS TABLE_SCHEMA
    , t.OBJECT_NAME AS TABLE_NAME
    , t.OBJECT_TYPE AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    SYS.ALL_OBJECTS t
WHERE
    t.OWNER NOT IN (
        'APEX_030200', 'APPQOSSYS', 'CTXSYS', 'DBSNMP', 'EXFSYS', 'FLOWS_FILES', 'IX', 'MDSYS', 'OLAPSYS',
        'ORDDATA', 'ORDSYS', 'ORDPLUGINS', 'OUTLN', 'OWBSYS', 'SYS', 'SYSTEM', 'SYSMAN', 'WMSYS', 'XDB',
        'XLS', 'SAVETODB_DEV', 'SAVETODB_XLS'
        )
    AND t.OBJECT_TYPE IN ('TABLE', 'VIEW', 'PROCEDURE')
    AND t.OBJECT_NAME NOT LIKE '%_INSERT'
    AND t.OBJECT_NAME NOT LIKE '%_UPDATE'
    AND t.OBJECT_NAME NOT LIKE '%_DELETE'
    AND t.OBJECT_NAME NOT LIKE '%_MERGE'
    AND t.OBJECT_NAME NOT LIKE '%_CHANGE'
    AND t.OBJECT_NAME NOT LIKE 'XL_%';
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    XLS.OBJECTS o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_SCHEMA IS NOT NULL
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL
    AND NOT o.TABLE_NAME LIKE 'XL_%'
;
